# MCP9808

This is a test description

- Device addresses: 24, 25, 26, 27, 28, 29, 30, 31
- Address type 7-bit

### Addr 1 16-bytes | # TUPPER and TLOWER Limit Hysteresis bits ## This bit can not be altered when either of the Lock bits are set (bit 6 and bit 7). This bit can be programmed in Shutdown mode. ### [10:9] | 2-bytes Read-only | # Shutdown Mode bit ## In shutdown, all power-consuming activities are disabled, though all registers can be written to or read. This bit cannot be set to ‘1’ when either of the Lock bits is set (bit 6 and bit 7). However, it can be cleared to ‘0’ for continuous conversion while locked. ### [8:8] | 1-byte Read-only